diff options
| author | Rémy Voet (ryv) <ryv@odoo.com> | 2020-12-31 08:33:31 +0000 |
|---|---|---|
| committer | Rémy Voet (ryv) <ryv@odoo.com> | 2021-01-21 13:44:58 +0000 |
| commit | 7dece58f1116e2ae669f7282bffb30cddf3d7624 (patch) | |
| tree | 830bfc5b3edd2666144719f9a848e96557d3b2dd /addons/mail/static/src/components/autocomplete_input | |
| parent | aae30ab4a8d559a516227830b3bb12f8e32213f2 (diff) | |
[FIX] stock: improve perf of replenishement report
Avoid to filter in a loop and use a read_group instead to group by
product-warehouse outside.
Also remove costly useless code.
Performance gain
----------------
On a large database (120K stock move, 5k product) where
+- 700 manual orderpoints will be create during the open of the
replenishement report:
Before:
16.14 +- 0.16 sec of python. (SQL time is +- 14 sec)
After:
1.33 +- 0.91 sec of python. (SQL time ==)
task-2390516
Diffstat (limited to 'addons/mail/static/src/components/autocomplete_input')
0 files changed, 0 insertions, 0 deletions
